==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QGraphicsOpacityEffect_shell.h <==
#ifndef QGRAPHICSOPACITYEFFECT_SHELL_H
#define QGRAPHICSOPACITYEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicseffect)

class QGraphicsOpacityEffect_shell : public QGraphicsOpacityEffect, public QtJambiShellInterface
{
public:
    QGraphicsOpacityEffect_shell(QObject* parent0 = nullptr);
    ~QGraphicsOpacityEffect_shell() override;

    QRectF boundingRectFor(const QRectF& sourceRect0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void draw(QPainter* painter0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sourceChanged(QGraphicsEffect::ChangeFlags flags0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsOpacityEffect_access : public QGraphicsOpacityEffect
{
    void __qt_draw_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
};

#endif // QT_CONFIG(graphicseffect)
#endif // QGRAPHICSOPACITYEFFECT_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QGraphicsOpacityEffect_shell.h <==
#ifndef QGRAPHICSOPACITYEFFECT_SHELL_H
#define QGRAPHICSOPACITYEFFECT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qbrush.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpixmap.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(graphicseffect)

class QGraphicsOpacityEffect_shell : public QGraphicsOpacityEffect, public QtJambiShellInterface
{
public:
    QGraphicsOpacityEffect_shell(QObject* parent0 = nullptr);
    ~QGraphicsOpacityEffect_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QGraphicsOpacityEffect_mshell;
    friend class QGraphicsOpacityEffect_oshell;
};


class QGraphicsOpacityEffect_mshell : public QGraphicsOpacityEffect_shell
{
public:
    using QGraphicsOpacityEffect_shell::QGraphicsOpacityEffect_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QGraphicsOpacityEffect_oshell : public QGraphicsOpacityEffect_mshell
{
public:
    using QGraphicsOpacityEffect_mshell::QGraphicsOpacityEffect_mshell;
    QRectF boundingRectFor(const QRectF& sourceRect0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void draw(QPainter* painter0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void sourceChanged(QGraphicsEffect::ChangeFlags flags0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGraphicsOpacityEffect_access : public QGraphicsOpacityEffect
{
    void __qt_draw_QPainter_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0);
};

#endif // QT_CONFIG(graphicseffect)
#endif // QGRAPHICSOPACITYEFFECT_SHELL_H
